@@ -1,8 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
-/*
- *  Authors: Jeffrey Stedfast <fejj@ximian.com>
- *
- *  Copyright 2002-2004 Ximian, Inc. (www.ximian.com)
+/*  GMime
+ *  Copyright (C) 2000-2007 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,8 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
- *
+ *  Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 
@@ -137,7 +134,7 @@ filter_filter (GMimeFilter *filter, char *in, size_t len, size_t prespace,
 		}
 	}
 	
-	g_mime_filter_backup (filter, last, inptr - last);
+	g_mime_filter_backup (filter, (char *) last, inptr - last);
 	
 	*out = filter->outbuf;
 	*outlen = outptr - filter->outbuf;
@@ -162,7 +159,8 @@ filter_reset (GMimeFilter *filter)
 /**
  * g_mime_filter_strip_new:
  *
- * Creates a new GMimeFilterStrip filter.
+ * Creates a new #GMimeFilterStrip filter which will strip trailing
+ * whitespace from every line of input passed through the filter.
  *
  * Returns a new strip filter.
  **/
